@@ -146,28 +146,28 @@ static int mail_check_timeout (gpointer data);
 static void after_mail_check (MailCheck *mc);
 
 static void applet_load_prefs(MailCheck *mc);
-static void applet_save_prefs(MailCheck *mc);
 
 #define WANT_BITMAPS(x) (x == REPORT_MAIL_USE_ANIMATION || x == REPORT_MAIL_USE_BITMAP)
 
-static void close_callback (GtkWidget *widget, void *data);
 
-static char *
+static G_CONST_RETURN char *
 mail_animation_filename (MailCheck *mc)
 {
-	if (!mc->animation_file){
+	if (!mc->animation_file) {
 		mc->animation_file =
-			gnome_unconditional_pixmap_file ("mailcheck/email.png");
-		if (g_file_exists (mc->animation_file))
-			return g_strdup (mc->animation_file);
-		g_free (mc->animation_file);
-		mc->animation_file = NULL;
-		return NULL;
-	} else if (*mc->animation_file){
-		if (g_file_exists (mc->animation_file))
-			return g_strdup (mc->animation_file);
+			gnome_program_locate_file (
+				NULL, GNOME_FILE_DOMAIN_PIXMAP,
+				"mailcheck/email.png", TRUE, NULL);
+
+		return mc->animation_file;
+
+	} else if (mc->animation_file [0]) {
+		if (g_file_test (mc->animation_file, G_FILE_TEST_EXISTS))
+			return mc->animation_file;
+
 		g_free (mc->animation_file);
 		mc->animation_file = NULL;
+
 		return NULL;
 	} else
 		/* we are using text only, since the filename was "" */
@@ -193,29 +193,46 @@ calc_dir_contents (char *dir)
        return size;
 }
 
-static void
-get_password_callback (gchar *string, gpointer data)
-{
-	gchar **pass = (gchar **)data;
-
-	*pass = string;
-}
-
-static gchar *
+static char *
 get_remote_password (void)
 {
-	gchar *pass = NULL;
 	GtkWidget *dialog;
+	GtkWidget *hbox;
+	GtkWidget *label;
+	GtkWidget *entry;
+	int        response;
+	char      *pass = NULL;
 
-	dialog = gnome_request_dialog(TRUE, _("Password:"), "",
-				      256, get_password_callback, &pass, NULL);
-	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-	gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+	dialog = gtk_dialog_new_with_buttons (
+			_("Mail check Applet"), NULL, 0,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
+	hbox = gtk_hbox_new (FALSE, 1);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+			    hbox, FALSE, FALSE, GNOME_PAD_SMALL);
+
+	label = gtk_label_new_with_mnemonic (_("_Password:"));
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+	entry = gtk_entry_new ();
+	gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
+	gtk_widget_show_all (hbox);
+
+	gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+
+	response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if (response == GTK_RESPONSE_OK)
+		pass = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+
+	gtk_widget_destroy (dialog);
 
 	return pass;
 }
 
-
 static void
 got_remote_answer (int mails, gpointer data)
 {
@@ -357,19 +374,21 @@ mailcheck_load_animation (MailCheck *mc, const char *fname)
 	int pbwidth, pbheight;
 	GdkPixbuf *pb;
 
-	if (mc->email_pixmap != NULL)
-		gdk_pixmap_unref(mc->email_pixmap);
-	if (mc->email_mask != NULL)
-		gdk_bitmap_unref(mc->email_mask);
+	if (mc->email_pixmap)
+		g_object_unref (mc->email_pixmap);
+
+	if (mc->email_mask)
+		g_object_unref (mc->email_mask);
+
 	mc->email_pixmap = NULL;
 	mc->email_mask = NULL;
 
 	pb = gdk_pixbuf_new_from_file (fname, NULL);
-	if (pb == NULL)
+	if (!pb)
 		return FALSE;
 
-	pbwidth = gdk_pixbuf_get_width(pb);
-	pbheight = gdk_pixbuf_get_height(pb);
+	pbwidth = gdk_pixbuf_get_width (pb);
+	pbheight = gdk_pixbuf_get_height (pb);
 
 	if(pbheight != mc->size) {
 		GdkPixbuf *pbt;
@@ -378,7 +397,7 @@ mailcheck_load_animation (MailCheck *mc, const char *fname)
 
 		pbt = gdk_pixbuf_scale_simple(pb, width, height,
 					      GDK_INTERP_NEAREST);
-		gdk_pixbuf_unref(pb);
+		g_object_unref (pb);
 		pb = pbt;
 	} else {
 		width = pbwidth;
@@ -398,7 +417,7 @@ mailcheck_load_animation (MailCheck *mc, const char *fname)
 					  &mc->email_mask,
 					  128);
 
-	gdk_pixbuf_unref (pb);
+	g_object_unref (pb);
 	
 	return TRUE;
 }
@@ -411,7 +430,9 @@ next_frame (gpointer data)
 	mc->nframe = (mc->nframe + 1) % mc->frames;
 	if (mc->nframe == 0)
 		mc->nframe = 1;
-	gtk_widget_draw (mc->da, NULL);
+
+	gtk_widget_queue_draw (mc->da);
+
 	return TRUE;
 }
 
@@ -452,9 +473,10 @@ after_mail_check (MailCheck *mc)
 			}
 			mc->nframe = 0;
 		}
-		gtk_widget_draw (mc->da, NULL);
+
+		gtk_widget_queue_draw (mc->da);
+
 		break;
-		
 	case REPORT_MAIL_USE_BITMAP:
 		if (mc->anymail){
 			if (mc->newmail)
@@ -463,9 +485,10 @@ after_mail_check (MailCheck *mc)
 				mc->nframe = 1;
 		} else
 			mc->nframe = 0;
-		gtk_widget_draw (mc->da, NULL);
-		break;
 
+		gtk_widget_queue_draw (mc->da);
+
+		break;
 	case REPORT_MAIL_USE_TEXT: {
 		char *text;
 
@@ -528,10 +551,13 @@ static gint
 icon_expose (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 {
 	MailCheck *mc = data;
-	int h = mc->size;
-	gdk_draw_pixmap (mc->da->window, mc->da->style->black_gc,
-			 mc->email_pixmap, mc->nframe * h,
-			 0, 0, 0, h, h);
+	int        h = mc->size;
+
+	gdk_draw_drawable (
+		mc->da->window, mc->da->style->black_gc,
+		mc->email_pixmap, mc->nframe * h,
+		0, 0, 0, h, h);
+
 	return TRUE;
 }
 
@@ -576,10 +602,11 @@ mailcheck_destroy (GtkWidget *widget, gpointer data)
 	g_free (mc->animation_file);
 	g_free (mc->mail_file);
 
-	if (mc->email_pixmap != NULL)
-		gdk_pixmap_unref (mc->email_pixmap);
-	if (mc->email_mask != NULL)
-		gdk_bitmap_unref (mc->email_mask);
+	if (mc->email_pixmap)
+		g_object_unref (mc->email_pixmap);
+
+	if (mc->email_mask)
+		g_object_unref (mc->email_mask);
 
 	if (mc->mail_timeout != 0)
 		gtk_timeout_remove (mc->mail_timeout);
@@ -599,7 +626,9 @@ mailcheck_destroy (GtkWidget *widget, gpointer data)
 static GtkWidget *
 create_mail_widgets (MailCheck *mc)
 {
-	char *fname = mail_animation_filename (mc);
+	const char *fname;
+
+	fname = mail_animation_filename (mc);
 
 	mc->ebox = gtk_event_box_new();
         gtk_widget_set_events(mc->ebox, 
@@ -626,8 +655,9 @@ create_mail_widgets (MailCheck *mc)
 	/* The drawing area */
 	mc->da = gtk_drawing_area_new ();
 	gtk_widget_ref (mc->da);
-	gtk_drawing_area_size (GTK_DRAWING_AREA(mc->da),
-			       mc->size, mc->size);
+
+	gtk_widget_set_size_request (mc->da, mc->size, mc->size);
+
 	g_signal_connect (G_OBJECT(mc->da), "expose_event", (GtkSignalFunc)icon_expose, mc);
 	gtk_widget_show (mc->da);
 
@@ -644,53 +674,88 @@ create_mail_widgets (MailCheck *mc)
 		mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
 		mc->containee = mc->label;
 	}
-	g_free (fname);
+
 	gtk_container_add (GTK_CONTAINER (mc->bin), mc->containee);
+
 	return mc->ebox;
 }
 
 static void
-set_selection (GtkWidget *widget, gpointer data)
+load_new_pixmap (MailCheck *mc)
 {
-	MailCheck *mc = g_object_get_data(G_OBJECT(widget), "MailCheck");
-	mc->selected_pixmap_name = data;
-	mc->anim_changed = TRUE;
+	gtk_widget_hide (mc->containee);
+	gtk_container_remove (GTK_CONTAINER (mc->bin), mc->containee);
+	
+	if (mc->selected_pixmap_name == mc->mailcheck_text_only) {
+		mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
+		mc->containee = mc->label;
+		g_free(mc->animation_file);
+		mc->animation_file = NULL;
+	} else {
+		char *fname;
+		char *full;
 
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (mc->property_window));
+		fname = g_build_filename ("mailcheck", mc->selected_pixmap_name, NULL);
+		full = gnome_program_locate_file (
+				NULL, GNOME_FILE_DOMAIN_PIXMAP,
+				fname, TRUE, NULL);
+		free (fname);
+		
+		if(full != NULL &&
+		   mailcheck_load_animation (mc, full)) {
+			mc->containee = mc->da;
+			g_free(mc->animation_file);
+			mc->animation_file = full;
+		} else {
+			g_free (full);
+			mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
+			mc->containee = mc->label;
+			g_free(mc->animation_file);
+			mc->animation_file = NULL;
+		}
+	}
+
+	mail_check_timeout (mc);
+
+	gtk_container_add (GTK_CONTAINER (mc->bin), mc->containee);
+	gtk_widget_show (mc->containee);
 }
 
 static void
-property_box_changed(GtkWidget *widget, gpointer data)
+animation_selected (GtkMenuItem *item, gpointer data)
 {
-	MailCheck *mc = data;
+	MailCheck *mc = g_object_get_data(G_OBJECT(item), "MailCheck");
+	mc->selected_pixmap_name = data;
 	
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (mc->property_window));
+	load_new_pixmap (mc);
+	panel_applet_gconf_set_string(mc->applet, "animation-file", 
+				      mc->animation_file, NULL);
 }
 
 static void
 mailcheck_new_entry (MailCheck *mc, GtkWidget *menu, GtkWidget *item, char *s)
 {
-	gtk_menu_append (GTK_MENU (menu), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 	g_object_set_data (G_OBJECT (item), "MailCheck", mc);
-
-	gtk_signal_connect_full (GTK_OBJECT (item), "activate",
-				 GTK_SIGNAL_FUNC (set_selection),
-				 NULL,
-				 g_strdup (s),
-				 (GtkDestroyNotify)g_free,
-				 FALSE, FALSE);
+	
+	g_signal_connect_data (item, "activate", G_CALLBACK (animation_selected),
+			       g_strdup (s), (GClosureNotify) g_free, 0);
 }
 
 static GtkWidget *
 mailcheck_get_animation_menu (MailCheck *mc)
 {
 	GtkWidget *omenu, *menu, *item;
-	struct    dirent *e;
-	char      *dname = gnome_unconditional_pixmap_file ("mailcheck");
+	struct     dirent *e;
+	char      *dname;
 	DIR       *dir;
-	const char      *basename = NULL;
-	int       i = 0, select_item = 0;
+	char      *basename = NULL;
+	int        i = 0, select_item = 0;
+
+	dname = gnome_program_locate_file (
+			NULL, GNOME_FILE_DOMAIN_PIXMAP,
+			"mailcheck", TRUE, NULL);
 
 	mc->selected_pixmap_name = mc->mailcheck_text_only;
 	omenu = gtk_option_menu_new ();
@@ -701,7 +766,7 @@ mailcheck_get_animation_menu (MailCheck *mc)
 	mailcheck_new_entry (mc, menu, item, mc->mailcheck_text_only);
 
 	if (mc->animation_file != NULL)
-		basename = g_basename (mc->animation_file);
+		basename = g_path_get_basename (mc->animation_file);
 	else
 		basename = NULL;
 
@@ -718,11 +783,14 @@ mailcheck_get_animation_menu (MailCheck *mc)
 				continue;
 
 			s = g_strdup (e->d_name);
+			/* FIXME the string s will be freed in a second so 
+			** this should be a strdup */
 			if (!mc->selected_pixmap_name)
 				mc->selected_pixmap_name = s;
 			if (basename && strcmp (basename, e->d_name) == 0)
 				select_item = i;
 			item = gtk_menu_item_new_with_label (s);
+			
 			i++;
 			gtk_widget_show (item);
 			
@@ -735,195 +803,19 @@ mailcheck_get_animation_menu (MailCheck *mc)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu), menu);
 	gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), select_item);
 	gtk_widget_show (omenu);
+
 	g_free (dname);
+	g_free (basename);
+
 	return omenu;
 }
 
-static void
-close_callback (GtkWidget *widget, gpointer data)
-{
-	MailCheck *mc = data;
-	mc->property_window = NULL;
-}
-
-static void
-load_new_pixmap (MailCheck *mc)
-{
-	gtk_widget_hide (mc->containee);
-	gtk_container_remove (GTK_CONTAINER (mc->bin), mc->containee);
-	
-	if (mc->selected_pixmap_name == mc->mailcheck_text_only) {
-		mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
-		mc->containee = mc->label;
-		g_free(mc->animation_file);
-		mc->animation_file = NULL;
-	} else {
-		char *fname = g_concat_dir_and_file ("mailcheck",
-						     mc->selected_pixmap_name);
-		char *full;
-		
-		full = gnome_pixmap_file (fname);
-		free (fname);
-		
-		if(full != NULL &&
-		   mailcheck_load_animation (mc, full)) {
-			mc->containee = mc->da;
-			g_free(mc->animation_file);
-			mc->animation_file = full;
-		} else {
-			g_free (full);
-			mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
-			mc->containee = mc->label;
-			g_free(mc->animation_file);
-			mc->animation_file = NULL;
-		}
-	}
-	mail_check_timeout (mc);
-	gtk_widget_set_uposition (GTK_WIDGET (mc->containee), 0, 0);
-	gtk_container_add (GTK_CONTAINER (mc->bin), mc->containee);
-	gtk_widget_show (mc->containee);
-}
-
-static void
-apply_properties_callback (GtkWidget *widget, gint page, gpointer data)
-{
-	const char *text;
-	MailCheck *mc = (MailCheck *)data;
-	
-	if(page!=-1) return;
-	
-	mc->update_freq = 1000 * (guint)(gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (mc->sec_spin)) + 
-					 60 * gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (mc->min_spin)));
-	/* do this here since we can no longer make the seconds
-	 * minimum 1
-	 */
-	if (mc->update_freq == 0) {
-		gtk_spin_button_set_value(GTK_SPIN_BUTTON (mc->sec_spin), 0.0);
-		gtk_spin_button_set_value(GTK_SPIN_BUTTON (mc->min_spin), 1.0);
-		mc->update_freq = 60*1000;
-	}
-
-	if(mc->mail_timeout != 0)
-		gtk_timeout_remove (mc->mail_timeout);
-	mc->mail_timeout = gtk_timeout_add (mc->update_freq, mail_check_timeout, mc);
-	
-	if (mc->clicked_cmd) {
-		g_free(mc->pre_check_cmd);
-		mc->pre_check_cmd = NULL;
-	}
-
-	text = gtk_entry_get_text (GTK_ENTRY(mc->pre_check_cmd_entry));
-	
-	if (strlen (text) > 0)
-		mc->pre_check_cmd = g_strdup (text);
-	mc->pre_check_enabled = GTK_TOGGLE_BUTTON(mc->pre_check_cmd_check)->active;
-	
-	if (mc->clicked_cmd) {
-		g_free(mc->clicked_cmd);
-		mc->clicked_cmd = NULL;
-        }
-
-        text = gtk_entry_get_text (GTK_ENTRY(mc->clicked_cmd_entry));
-
-        if (strlen(text) > 0)
-                mc->clicked_cmd = g_strdup(text);
-	mc->clicked_enabled = GTK_TOGGLE_BUTTON(mc->clicked_cmd_check)->active;
-
-	if (mc->newmail_cmd) {
-		g_free(mc->newmail_cmd);
-		mc->newmail_cmd = NULL;
-	}
-
-	text = gtk_entry_get_text (GTK_ENTRY(mc->newmail_cmd_entry));
-
-	if (strlen(text) > 0)
-		mc->newmail_cmd = g_strdup(text);
-	mc->newmail_enabled = GTK_TOGGLE_BUTTON(mc->newmail_cmd_check)->active;
-
-	if (mc->anim_changed)
-		load_new_pixmap (mc);
-	
-	mc->anim_changed = FALSE;
-        
-	if (mc->mail_file) {
-		g_free(mc->mail_file);
-		mc->mail_file = NULL;
-	}
-
-	text = gtk_entry_get_text (GTK_ENTRY (mc->mailfile_entry));
-
-	if (strlen(text) > 0)
-		mc->mail_file = g_strdup(text);
-
-	if (mc->remote_server) {
-		g_free(mc->remote_server);
-		mc->remote_server = NULL;
-	}
-
-        text = gtk_entry_get_text (GTK_ENTRY(mc->remote_server_entry));
-	
-	if (strlen(text) > 0)
-		mc->remote_server = g_strdup(text);
-
-	if (mc->remote_username) {
-		g_free(mc->remote_username);
-		mc->remote_username = NULL;
-	}
-
-        text = gtk_entry_get_text (GTK_ENTRY(mc->remote_username_entry));
-
-	if (strlen(text) > 0)
-		mc->remote_username = g_strdup(text);
-
-	if (mc->remote_password) {
-		g_free(mc->remote_password);
-		mc->remote_password = NULL;
-	}
-
-        text = gtk_entry_get_text (GTK_ENTRY(mc->remote_password_entry));
-
-	if (strlen(text) > 0)
-		mc->remote_password = g_strdup(text);
-
-        if (mc->remote_folder) {
-                g_free(mc->remote_folder);
-                mc->remote_folder = NULL;
-        }
- 
-        text = gtk_entry_get_text (GTK_ENTRY(mc->remote_folder_entry));
- 
-        if (strlen(text) > 0)
-                mc->remote_folder = g_strdup(text);
-
-	if (mc->pre_remote_command) {
-		g_free(mc->pre_remote_command);
-		mc->pre_remote_command = NULL;
-	}
-
-        text = gtk_entry_get_text (GTK_ENTRY(mc->pre_remote_command_entry));
-	
-	if (strlen(text) > 0)
-		mc->pre_remote_command = g_strdup(text);
-        
-	mc->mailbox_type = mc->mailbox_type_temp;
-
-	mc->play_sound = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(mc->play_sound_check));
-
-	if ((mc->mailbox_type != MAILBOX_POP3) &&
-	    (mc->mailbox_type != MAILBOX_IMAP) &&
-	    (mc->remote_handle != NULL)) {
-		helper_whack_handle (mc->remote_handle);
-		mc->remote_handle = NULL;
-	}
-	applet_save_prefs(mc);
-}
-
 static void
 make_remote_widgets_sensitive(MailCheck *mc)
 {
-	gboolean b = mc->mailbox_type_temp != MAILBOX_LOCAL &&
-	             mc->mailbox_type_temp != MAILBOX_LOCALDIR;
-        gboolean f = mc->mailbox_type_temp == MAILBOX_IMAP;
+	gboolean b = mc->mailbox_type != MAILBOX_LOCAL &&
+	             mc->mailbox_type != MAILBOX_LOCALDIR;
+        gboolean f = mc->mailbox_type == MAILBOX_IMAP;
 	
 	gtk_widget_set_sensitive (mc->mailfile_fentry, !b);
 	gtk_widget_set_sensitive (mc->mailfile_label, !b);
@@ -940,14 +832,244 @@ make_remote_widgets_sensitive(MailCheck *mc)
 	gtk_widget_set_sensitive (mc->pre_remote_command_label, b);
 }
 
+static void
+mail_file_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->mail_file);
+		g_free (mc->mail_file);
+		
+	mc->mail_file = text;
+	panel_applet_gconf_set_string(mc->applet, "mail-file", mc->mail_file, NULL);
+}
+
+static void
+remote_server_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->remote_server);
+		g_free (mc->remote_server);
+		
+	mc->remote_server = text;
+	panel_applet_gconf_set_string(mc->applet, "remote-server", 
+				      mc->remote_server, NULL);
+}
+
+static void
+remote_username_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->remote_username);
+		g_free (mc->remote_username);
+		
+	mc->remote_username = text;
+	panel_applet_gconf_set_string(mc->applet, "remote-username", 
+				      mc->remote_username, NULL);
+}
+
+static void
+remote_password_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->remote_password);
+		g_free (mc->remote_password);
+		
+	mc->remote_password = text;
+	panel_applet_gconf_set_string(mc->applet, "remote-password", 
+				      mc->remote_password, NULL);
+}
+
+static void
+remote_folder_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->remote_folder);
+		g_free (mc->remote_folder);
+		
+	mc->remote_folder = text;
+	panel_applet_gconf_set_string(mc->applet, "remote-folder", 
+				      mc->remote_folder, NULL);
+}
+
+static void
+pre_remote_command_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->pre_remote_command);
+		g_free (mc->pre_remote_command);
+		
+	mc->pre_remote_command = text;
+	panel_applet_gconf_set_string(mc->applet, "pre-remote-command", 
+				      mc->pre_remote_command, NULL);
+}	
+
 static void 
 set_mailbox_selection (GtkWidget *widget, gpointer data)
 {
 	MailCheck *mc = g_object_get_data(G_OBJECT(widget), "MailCheck");
-	mc->mailbox_type_temp = GPOINTER_TO_INT(data);
-        
+	mc->mailbox_type = GPOINTER_TO_INT(data);
+        panel_applet_gconf_set_int(mc->applet, "mailbox-type", 
+        			  (gint)mc->mailbox_type, NULL);
         make_remote_widgets_sensitive(mc);
-	gnome_property_box_changed (GNOME_PROPERTY_BOX (mc->property_window));
+        
+        if ((mc->mailbox_type != MAILBOX_POP3) &&
+	    (mc->mailbox_type != MAILBOX_IMAP) &&
+	    (mc->remote_handle != NULL)) {
+		helper_whack_handle (mc->remote_handle);
+		mc->remote_handle = NULL;
+	}
+}
+
+static void
+pre_check_toggled (GtkToggleButton *button, gpointer data)
+{
+	MailCheck *mc = data;
+	
+	mc->pre_check_enabled = gtk_toggle_button_get_active (button);
+	panel_applet_gconf_set_bool(mc->applet, "exec-enabled", 
+				    mc->pre_check_enabled, NULL);
+				    
+}
+
+static void
+pre_check_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->pre_check_cmd)
+		g_free (mc->pre_check_cmd);	
+	mc->pre_check_cmd = g_strdup (text);
+	panel_applet_gconf_set_string(mc->applet, "exec-command", 
+				      mc->pre_check_cmd, NULL);
+	g_free (text);
+	
+}
+
+static void
+newmail_toggled (GtkToggleButton *button, gpointer data)
+{
+	MailCheck *mc = data;
+	
+	mc->newmail_enabled = gtk_toggle_button_get_active (button);
+	panel_applet_gconf_set_bool(mc->applet, "newmail-enabled", 
+				    mc->newmail_enabled, NULL);
+				    
+}
+
+static void
+newmail_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->newmail_cmd)
+		g_free (mc->newmail_cmd);	
+	mc->newmail_cmd = g_strdup (text);
+	panel_applet_gconf_set_string(mc->applet, "newmail-command", 
+				      mc->newmail_cmd, NULL);
+	g_free (text);
+	
+}
+
+static void
+clicked_toggled (GtkToggleButton *button, gpointer data)
+{
+	MailCheck *mc = data;
+	
+	mc->clicked_enabled = gtk_toggle_button_get_active (button);
+	panel_applet_gconf_set_bool(mc->applet, "clicked-enabled", 
+				    mc->clicked_enabled, NULL);
+				    
+}
+
+static void
+clicked_changed (GtkEntry *entry, gpointer data)
+{
+	MailCheck *mc = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	if (!text)
+		return;
+		
+	if (mc->clicked_cmd)
+		g_free (mc->clicked_cmd);	
+	mc->clicked_cmd = g_strdup (text);
+	panel_applet_gconf_set_string(mc->applet, "clicked-command", mc->clicked_cmd, NULL);
+	g_free (text);
+	
+}
+
+static void
+update_spin_changed (GtkSpinButton *spin, gpointer data)
+{
+	MailCheck *mc = data;
+	
+	mc->update_freq = 1000 * (guint)(gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (mc->sec_spin)) + 60 * gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (mc->min_spin)));
+	
+	if (mc->update_freq == 0) {
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON (mc->sec_spin), 0.0);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON (mc->min_spin), 1.0);
+		mc->update_freq = 60*1000;
+	}
+	if(mc->mail_timeout != 0)
+		gtk_timeout_remove (mc->mail_timeout);
+	mc->mail_timeout = gtk_timeout_add (mc->update_freq, mail_check_timeout, mc);
+	panel_applet_gconf_set_int(mc->applet, "update-frequency", mc->update_freq, NULL);
+}
+
+static void
+sound_toggled (GtkToggleButton *button, gpointer data)
+{
+	MailCheck *mc = data;
+	
+	mc->play_sound = gtk_toggle_button_get_active (button);
+	panel_applet_gconf_set_bool(mc->applet, "play-sound", mc->play_sound, NULL);
 }
 
 static GtkWidget *
@@ -978,7 +1100,7 @@ mailbox_properties_page(MailCheck *mc)
 	g_signal_connect (G_OBJECT(item), "activate", 
 			    G_CALLBACK(set_mailbox_selection), 
 			    GINT_TO_POINTER(MAILBOX_LOCAL));
-	gtk_menu_append(GTK_MENU(l2), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (l2), item);
 
 	item = gtk_menu_item_new_with_label(_("Local maildir")); 
 	gtk_widget_show(item);
@@ -986,7 +1108,7 @@ mailbox_properties_page(MailCheck *mc)
 	g_signal_connect (G_OBJECT(item), "activate", 
 			    G_CALLBACK(set_mailbox_selection), 
 			    GINT_TO_POINTER(MAILBOX_LOCALDIR));
-	gtk_menu_append(GTK_MENU(l2), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (l2), item);
 
 	item = gtk_menu_item_new_with_label(_("Remote POP3-server")); 
 	gtk_widget_show(item);
@@ -995,14 +1117,14 @@ mailbox_properties_page(MailCheck *mc)
 			    G_CALLBACK(set_mailbox_selection), 
 			    GINT_TO_POINTER(MAILBOX_POP3));
         
-	gtk_menu_append(GTK_MENU(l2), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (l2), item);
 	item = gtk_menu_item_new_with_label(_("Remote IMAP-server")); 
 	gtk_widget_show(item);
 	g_object_set_data(G_OBJECT(item), "MailCheck", mc);
 	g_signal_connect (G_OBJECT(item), "activate", 
 			    G_CALLBACK(set_mailbox_selection), 
 			    GINT_TO_POINTER(MAILBOX_IMAP));
-	gtk_menu_append(GTK_MENU(l2), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (l2), item);
 	
 	gtk_widget_show(l2);
   
@@ -1020,14 +1142,14 @@ mailbox_properties_page(MailCheck *mc)
 	gtk_widget_show(l);
 	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
 
-	mc->mailfile_fentry = l = gnome_file_entry_new ("spool file", _("Browse"));
+	mc->mailfile_fentry = l = gnome_file_entry_new ("spool_file", _("Browse"));
 	gtk_widget_show(l);
 	gtk_box_pack_start (GTK_BOX (hbox), l, TRUE, TRUE, 0);
 
 	mc->mailfile_entry = l = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY (l));
 	gtk_entry_set_text(GTK_ENTRY(l), mc->mail_file);
 	g_signal_connect(G_OBJECT(l), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(mail_file_changed), mc);
 
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
@@ -1044,7 +1166,7 @@ mailbox_properties_page(MailCheck *mc)
 	gtk_box_pack_start (GTK_BOX (hbox), l, TRUE, TRUE, 0);      
 	
 	g_signal_connect(G_OBJECT(l), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(remote_server_changed), mc);
 	
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
@@ -1062,7 +1184,7 @@ mailbox_properties_page(MailCheck *mc)
 	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);      
   
 	g_signal_connect(G_OBJECT(l), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(remote_username_changed), mc);
 
 	mc->remote_password_label = l = gtk_label_new(_("Password:"));
 	gtk_widget_show(l);
@@ -1076,7 +1198,7 @@ mailbox_properties_page(MailCheck *mc)
 	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);      
 	
 	g_signal_connect(G_OBJECT(l), "changed",
-                     G_CALLBACK(property_box_changed), mc);
+                     G_CALLBACK(remote_password_changed), mc);
 
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
@@ -1094,13 +1216,13 @@ mailbox_properties_page(MailCheck *mc)
         gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
   
         g_signal_connect(G_OBJECT(l), "changed",
-                           G_CALLBACK(property_box_changed), mc);
+                           G_CALLBACK(remote_folder_changed), mc);
  
         hbox = gtk_hbox_new (FALSE, 6);
         gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
         gtk_widget_show (hbox);  
 
-	mc->pre_remote_command_label = l = gtk_label_new(_("Command to run before we check for mail:"));
+	mc->pre_remote_command_label = l = gtk_label_new(_("Command to run before checking for mail:"));
 	gtk_widget_show(l);
 	gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
   
@@ -1111,7 +1233,7 @@ mailbox_properties_page(MailCheck *mc)
 	gtk_box_pack_start (GTK_BOX (hbox), l, TRUE, TRUE, 0);      
 	
 	g_signal_connect(G_OBJECT(l), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(pre_remote_command_changed), mc);
   
 	make_remote_widgets_sensitive(mc);
 	
@@ -1144,7 +1266,7 @@ mailcheck_properties_page (MailCheck *mc)
 	l = gtk_check_button_new_with_label(_("Before each update:"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->pre_check_enabled);
 	g_signal_connect(G_OBJECT(l), "toggled",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(pre_check_toggled), mc);
 	gtk_widget_show(l);
 	mc->pre_check_cmd_check = l;
 	
@@ -1157,7 +1279,7 @@ mailcheck_properties_page (MailCheck *mc)
 		gtk_entry_set_text(GTK_ENTRY(mc->pre_check_cmd_entry), 
 				   mc->pre_check_cmd);
 	g_signal_connect(G_OBJECT(mc->pre_check_cmd_entry), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(pre_check_changed), mc);
 	gtk_widget_show(mc->pre_check_cmd_entry);
 	gtk_table_attach_defaults (GTK_TABLE (table), mc->pre_check_cmd_entry,
 				   1, 2, 0, 1);
@@ -1165,7 +1287,7 @@ mailcheck_properties_page (MailCheck *mc)
 	l = gtk_check_button_new_with_label (_("When new mail arrives:"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->newmail_enabled);
 	g_signal_connect(G_OBJECT(l), "toggled",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(newmail_toggled), mc);
 	gtk_widget_show(l);
 	gtk_table_attach (GTK_TABLE (table), l, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 	mc->newmail_cmd_check = l;
@@ -1176,7 +1298,7 @@ mailcheck_properties_page (MailCheck *mc)
 				   mc->newmail_cmd);
 	}
 	g_signal_connect(G_OBJECT (mc->newmail_cmd_entry), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(newmail_changed), mc);
 	gtk_widget_show(mc->newmail_cmd_entry);
 	gtk_table_attach_defaults (GTK_TABLE (table), mc->newmail_cmd_entry,
 				    1, 2, 1, 2);
@@ -1184,7 +1306,7 @@ mailcheck_properties_page (MailCheck *mc)
         l = gtk_check_button_new_with_label (_("When clicked:"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->clicked_enabled);
 	g_signal_connect(G_OBJECT(l), "toggled",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(clicked_toggled), mc);
         gtk_widget_show(l);
 	gtk_table_attach (GTK_TABLE (table), l, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
 	mc->clicked_cmd_check = l;
@@ -1195,7 +1317,7 @@ mailcheck_properties_page (MailCheck *mc)
 				   mc->clicked_cmd);
         }
         g_signal_connect(G_OBJECT(mc->clicked_cmd_entry), "changed",
-                           G_CALLBACK(property_box_changed), mc);
+                           G_CALLBACK(clicked_changed), mc);
         gtk_widget_show(mc->clicked_cmd_entry);
 	gtk_table_attach_defaults (GTK_TABLE (table), mc->clicked_cmd_entry,
 				   1, 2, 2, 3);
@@ -1210,10 +1332,12 @@ mailcheck_properties_page (MailCheck *mc)
 
 	freq_a = gtk_adjustment_new((float)((mc->update_freq/1000)/60), 0, 1440, 1, 5, 5);
 	mc->min_spin = gtk_spin_button_new( GTK_ADJUSTMENT (freq_a), 1, 0);
-	g_signal_connect(G_OBJECT(freq_a), "value_changed",
+	/*g_signal_connect(G_OBJECT(freq_a), "value_changed",
 			   G_CALLBACK(property_box_changed), mc);
 	g_signal_connect(G_OBJECT(mc->min_spin), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(property_box_changed), mc);*/
+	g_signal_connect (G_OBJECT (mc->min_spin), "value_changed",
+			  G_CALLBACK (update_spin_changed), mc);			  
 	gtk_box_pack_start (GTK_BOX (hbox), mc->min_spin,  FALSE, FALSE, 0);
 	gtk_widget_show(mc->min_spin);
 	
@@ -1223,10 +1347,12 @@ mailcheck_properties_page (MailCheck *mc)
 	
 	freq_a = gtk_adjustment_new((float)((mc->update_freq/1000)%60), 0, 59, 1, 5, 5);
 	mc->sec_spin  = gtk_spin_button_new (GTK_ADJUSTMENT (freq_a), 1, 0);
-	g_signal_connect(G_OBJECT(freq_a), "value_changed",
+	/*g_signal_connect(G_OBJECT(freq_a), "value_changed",
 			   G_CALLBACK(property_box_changed), mc);
 	g_signal_connect(G_OBJECT(mc->sec_spin), "changed",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(property_box_changed), mc);*/
+	g_signal_connect (G_OBJECT (mc->sec_spin), "value_changed",
+			  G_CALLBACK (update_spin_changed), mc);
 	gtk_box_pack_start (GTK_BOX (hbox), mc->sec_spin,  FALSE, FALSE, 0);
 	gtk_widget_show(mc->sec_spin);
 	
@@ -1237,7 +1363,7 @@ mailcheck_properties_page (MailCheck *mc)
 	mc->play_sound_check = gtk_check_button_new_with_label(_("Play a sound when new mail arrives"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(mc->play_sound_check), mc->play_sound);
 	g_signal_connect(G_OBJECT(mc->play_sound_check), "toggled",
-			   G_CALLBACK(property_box_changed), mc);
+			   G_CALLBACK(sound_toggled), mc);
 	gtk_widget_show(mc->play_sound_check);
 	gtk_box_pack_start(GTK_BOX (vbox), mc->play_sound_check, FALSE, FALSE, 0);
 
@@ -1254,10 +1380,10 @@ mailcheck_properties_page (MailCheck *mc)
 	return vbox;
 }
 
+#ifdef FIXME
 static void
 phelp_cb (GtkWidget *w, gint tab, gpointer data)
 {
-#ifdef FIXME
 	GnomeHelpMenuEntry help_entry = { "mailcheck_applet", NULL };
 
 	char *das_names[] =  { "index.html#MAILCHECK-PREFS",
@@ -1265,43 +1391,58 @@ phelp_cb (GtkWidget *w, gint tab, gpointer data)
 
 	help_entry.path = das_names[((MailCheck *)data)->type];
 	gnome_help_display(NULL, &help_entry);
-#endif
 }	
+#endif
+
+static void
+response_cb (GtkDialog *dialog, gint id, gpointer data)
+{
+	MailCheck *mc = data;
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	mc->property_window = NULL;
+	
+}
+
 
 static void
 mailcheck_properties (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	GtkWidget *p;
+	GtkWidget *notebook;
 
 	MailCheck *mc = data;
 
 	if (mc->property_window != NULL) {
-		gdk_window_raise(mc->property_window->window);
+		gtk_window_present (GTK_WINDOW (mc->property_window));
 		return; /* Only one instance of the properties dialog! */
 	}
 	
-	mc->property_window = gnome_property_box_new ();
-	gtk_window_set_wmclass (GTK_WINDOW (mc->property_window),
-				"mailcheck", "Mailcheck");
-	gtk_window_set_title (GTK_WINDOW (mc->property_window),
-			      _("Mail check properties"));
+	mc->property_window = gtk_dialog_new_with_buttons (_("Inbox Monitor Properties"), 
+							   NULL,
+						           GTK_DIALOG_DESTROY_WITH_PARENT,
+						           GTK_STOCK_CLOSE, 
+						           GTK_RESPONSE_CLOSE,
+						           NULL);
 	gnome_window_icon_set_from_file (GTK_WINDOW (mc->property_window),
 					 GNOME_ICONDIR"/gnome-mailcheck.png");
-
+	
+	
+	notebook = gtk_notebook_new ();
+	gtk_widget_show (notebook);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (mc->property_window)->vbox), notebook,
+			    TRUE, TRUE, 0);
 	p = mailcheck_properties_page (mc);
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX(mc->property_window),
-					p, gtk_label_new (_("Mail check")));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), p,
+				  gtk_label_new_with_mnemonic (_("_Mail check")));
+				  
 	p = mailbox_properties_page (mc);
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX(mc->property_window),
-					p, gtk_label_new (_("Mailbox")));
-
-	g_signal_connect (G_OBJECT (mc->property_window), "apply",
-			    G_CALLBACK(apply_properties_callback), mc);
-	g_signal_connect (G_OBJECT (mc->property_window), "destroy",
-			    G_CALLBACK(close_callback), mc);
-	g_signal_connect (G_OBJECT (mc->property_window), "help",
-			    G_CALLBACK(phelp_cb), mc);
-
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), p,
+				  gtk_label_new_with_mnemonic (_("Mail_box")));
+	
+	g_signal_connect (G_OBJECT (mc->property_window), "response",
+			  G_CALLBACK (response_cb), mc);
+	gtk_widget_show (GTK_DIALOG (mc->property_window)->vbox);
 	gtk_widget_show (mc->property_window);
 }
 
@@ -1318,13 +1459,18 @@ applet_load_prefs(MailCheck *mc)
 {
 	gchar *query;
 
-	query = gnome_unconditional_pixmap_file("mailcheck/email.png");
+	query = gnome_program_locate_file (
+			NULL, GNOME_FILE_DOMAIN_PIXMAP,
+			"mailcheck/email.png", FALSE, NULL);
+
 	mc->animation_file = panel_applet_gconf_get_string(mc->applet, "animation-file", NULL);
 	if(!mc->animation_file || strcmp(mc->animation_file, "none")) {
 		g_free(mc->animation_file);
 		mc->animation_file = g_strdup(query);
 	}
+
 	g_free(query);
+
 	mc->update_freq = panel_applet_gconf_get_int(mc->applet, "update-frequency", NULL);
 	mc->pre_check_cmd = panel_applet_gconf_get_string(mc->applet, "exec-command", NULL);
 	mc->pre_check_enabled = panel_applet_gconf_get_bool(mc->applet, "exec-enabled", NULL);
@@ -1345,27 +1491,6 @@ applet_load_prefs(MailCheck *mc)
 	mc->play_sound = panel_applet_gconf_get_bool(mc->applet, "play-sound", NULL);
 }
 
-static void
-applet_save_prefs(MailCheck *mc)
-{
-	panel_applet_gconf_set_string(mc->applet, "animation-file", mc->animation_file, NULL);
-	panel_applet_gconf_set_int(mc->applet, "update-frequency", mc->update_freq, NULL);
-	panel_applet_gconf_set_string(mc->applet, "exec-command", mc->pre_check_cmd, NULL);
-	panel_applet_gconf_set_bool(mc->applet, "exec-enabled", mc->pre_check_enabled, NULL);
-	panel_applet_gconf_set_string(mc->applet, "newmail-command", mc->newmail_cmd, NULL);
-	panel_applet_gconf_set_bool(mc->applet, "newmail-enabled", mc->newmail_enabled, NULL);
-	panel_applet_gconf_set_string(mc->applet, "clicked-command", mc->clicked_cmd, NULL);
-	panel_applet_gconf_set_bool(mc->applet, "clicked-enabled", mc->clicked_enabled, NULL);
-	panel_applet_gconf_set_string(mc->applet, "mail-file", mc->mail_file, NULL);
-	panel_applet_gconf_set_string(mc->applet, "remote-server", mc->remote_server, NULL);
-	panel_applet_gconf_set_string(mc->applet, "remote-username", mc->remote_username, NULL);
-	panel_applet_gconf_set_string(mc->applet, "remote-password", mc->remote_password, NULL);
-	panel_applet_gconf_set_string(mc->applet, "remote-folder", mc->remote_folder, NULL);
-	panel_applet_gconf_set_string(mc->applet, "pre-remote-command", mc->pre_remote_command, NULL);
-	panel_applet_gconf_set_int(mc->applet, "mailbox-type", (gint)mc->mailbox_type, NULL);
-	panel_applet_gconf_set_bool(mc->applet, "play-sound", mc->play_sound, NULL);
-}
-
 static void
 mailcheck_about(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
@@ -1409,7 +1534,7 @@ static void
 applet_change_pixel_size(PanelApplet * w, gint size, gpointer data)
 {
 	MailCheck *mc = data;
-	char *fname;
+	const char *fname;
 
 	if(mc->report_mail_mode == REPORT_MAIL_USE_TEXT)
 		return;
@@ -1417,23 +1542,25 @@ applet_change_pixel_size(PanelApplet * w, gint size, gpointer data)
 	mc->size = size;
 	fname = mail_animation_filename (mc);
 
-	gtk_drawing_area_size (GTK_DRAWING_AREA(mc->da),size,size);
 	gtk_widget_set_size_request (GTK_WIDGET(mc->da), size, size);
 	
 	if (!fname)
 		return;
 
 	mailcheck_load_animation (mc, fname);
-	g_free (fname);
 }
 
 static void
 help_callback (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-#ifdef FIXME
-	GnomeHelpMenuEntry help_ref = { "mailcheck_applet", "index.html"};
-	gnome_help_display (NULL, &help_ref);
-#endif
+	GError *error = NULL;
+
+	gnome_help_display_desktop (
+			NULL, "mailcheck", "mailcheck", NULL, &error);
+	if (error) {
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+	}
 }
 
 static const BonoboUIVerb mailcheck_menu_verbs [] = {
@@ -1444,17 +1571,6 @@ static const BonoboUIVerb mailcheck_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char mailcheck_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Properties Item\" verb=\"Properties\" _label=\"Properties ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Help Item\" verb=\"Help\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"About Item\" verb=\"About\" _label=\"About ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"   <menuitem name=\"Check Item\" verb=\"Check\" _label=\"Check for mail\"/>\n"
-	"</popup>\n";
-	
 gboolean
 fill_mailcheck_applet(PanelApplet *applet)
 {
@@ -1508,8 +1624,12 @@ fill_mailcheck_applet(PanelApplet *applet)
 			 G_CALLBACK(exec_clicked_cmd), mc);
 
 
-	panel_applet_setup_menu (applet, mailcheck_menu_xml, 
-			         mailcheck_menu_verbs, mc);
+	panel_applet_setup_menu_from_file (applet,
+					   NULL,
+					   "GNOME_MailCheckApplet.xml",
+					   NULL, 
+			        	   mailcheck_menu_verbs,
+					   mc);
 	
 	gtk_widget_show (GTK_WIDGET (applet));
 
