@@ -318,16 +318,11 @@ create_launcher (const char *parameters, GnomeDesktopItem *ditem)
 	if (!default_app_pixmap)
 		default_app_pixmap = panel_pixmap_discovery ("gnome-unknown.png",
 							     FALSE /* fallback */);
-#ifdef LAUNCHER_DEBUG
-	printf ("Creating Launcher %s\n", parameters);
-#endif
 	if (ditem == NULL) {
 		if (parameters == NULL) {
 			return NULL;
 		}
-#ifdef LAUNCHER_DEBUG
-	printf ("Creating gnome_desktop_item_new_from_uri\n");
-#endif
+
 		ditem = gnome_desktop_item_new_from_uri (parameters,
 							 0 /* flags */,
 							 NULL /* error */);
@@ -521,6 +516,20 @@ launcher_changed (GtkObject *dedit, gpointer data)
 	properties_apply (launcher);
 }
 
+static void
+set_revert_insensitive (GtkWidget *button,	
+			gpointer   dummy)
+{
+     gtk_widget_set_sensitive (button, FALSE);
+}
+
+static void
+set_revert_sensitive (GtkWidget *button,
+		      gpointer   dummy)
+{
+     gtk_widget_set_sensitive (button, TRUE);
+}
+
 static void
 window_response (GtkWidget *w, int response, gpointer data)
 {
@@ -560,18 +569,23 @@ static GtkWidget *
 create_properties_dialog (Launcher *launcher)
 {
 	GtkWidget *dialog;
+        GtkWidget *help;
+        GtkWidget *close;
+        GtkWidget *revert;
 
-	/* watch the enum at the top of the file */
-	dialog = gtk_dialog_new_with_buttons (_("Launcher properties"),
-					      NULL /* parent */,
-					      0 /* flags */,
-					      GTK_STOCK_HELP,
-					      GTK_RESPONSE_HELP,
-					      GTK_STOCK_REVERT_TO_SAVED,
-					      REVERT_BUTTON,
-					      GTK_STOCK_CLOSE,
-					      GTK_RESPONSE_CLOSE,
-					      NULL);
+	dialog = gtk_dialog_new ();
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Launcher properties"));
+
+	help = gtk_dialog_add_button (
+			GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
+
+	revert = gtk_dialog_add_button (
+			GTK_DIALOG (dialog), GTK_STOCK_REVERT_TO_SAVED, REVERT_BUTTON);
+        gtk_widget_set_sensitive (revert, FALSE);
+
+	close = gtk_dialog_add_button (
+			GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
 	launcher->dedit = gnome_ditem_edit_new ();
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
@@ -587,19 +601,27 @@ create_properties_dialog (Launcher *launcher)
 	gnome_ditem_edit_set_ditem (GNOME_DITEM_EDIT (launcher->dedit),
 				    launcher->ditem);
 
-	g_signal_connect (G_OBJECT (launcher->dedit), "changed",
-			    G_CALLBACK (launcher_changed),
-			    launcher);
+	g_signal_connect (launcher->dedit, "changed",
+			  G_CALLBACK (launcher_changed),
+			  launcher);
 
-	g_signal_connect (G_OBJECT (dialog), "destroy",
-			    G_CALLBACK (properties_close_callback),
-			    launcher);
+        g_signal_connect_swapped (launcher->dedit, "changed",
+				  G_CALLBACK (set_revert_sensitive),
+				  revert);
+
+	g_signal_connect (dialog, "destroy",
+			  G_CALLBACK (properties_close_callback),
+			  launcher);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 
-	g_signal_connect (G_OBJECT (dialog), "response",
-			    G_CALLBACK (window_response),
-			    launcher);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (window_response),
+			  launcher);
+
+	g_signal_connect (revert, "clicked",
+			  G_CALLBACK (set_revert_insensitive),
+			  NULL);
 
 	gnome_ditem_edit_grab_focus (GNOME_DITEM_EDIT (launcher->dedit));
 
