@@ -59,7 +59,7 @@
 GSList *panel_list = NULL;
 
 static gboolean panel_dragged = FALSE;
-static int panel_dragged_timeout = -1;
+static guint panel_dragged_timeout = 0;
 static gboolean panel_been_moved = FALSE;
 
 /*the number of base panels (corner/snapped) out there, never let it
@@ -559,7 +559,7 @@ panel_move_timeout(gpointer data)
 		move_panel_to_cursor(data);
 	
 	panel_been_moved = FALSE;
-	panel_dragged_timeout = -1;
+	panel_dragged_timeout = 0;
 
 	return FALSE;
 }
@@ -576,16 +576,17 @@ panel_remove_applets (PanelWidget *panel)
 		info = g_object_get_data (G_OBJECT (ad->applet),
 					  "applet_info");
 
-		panel_applet_save_position (info, info->gconf_key);
+		if (info->type == APPLET_BONOBO) {
+			PanelAppletFrame *frame = info->data;
 
-		if (info->type == APPLET_SWALLOW) {
+			panel_applet_frame_set_clean_remove
+				(PANEL_APPLET_FRAME (frame), TRUE);
+		} else if (info->type == APPLET_SWALLOW) {
 			Swallow *swallow = info->data;
 
 			swallow->clean_remove = TRUE;
 		}
 	}
-
-	gnome_config_sync ();
 }
 
 static void
@@ -624,7 +625,7 @@ panel_destroy (GtkWidget *widget, gpointer data)
 	}
 
 	if (pd->menu != NULL)
-		gtk_widget_unref (pd->menu);
+		g_object_unref (G_OBJECT (pd->menu));
 	pd->menu = NULL;
 
 	pd->panel = NULL;
@@ -633,6 +634,8 @@ panel_destroy (GtkWidget *widget, gpointer data)
 		g_source_remove (pd->deactivate_idle);
 	pd->deactivate_idle = 0;
 
+	g_object_set_data (G_OBJECT (widget), "PanelData", NULL);
+
 	panel_list = g_slist_remove (panel_list, pd);
 	g_free (pd);
 }
@@ -640,7 +643,15 @@ panel_destroy (GtkWidget *widget, gpointer data)
 static void
 panel_applet_move(PanelWidget *panel, GtkWidget *widget, gpointer data)
 {
-	applets_to_sync = TRUE;
+	AppletInfo *info;
+
+	info = g_object_get_data (G_OBJECT (widget), "applet_info");
+
+	g_return_if_fail (info);
+
+	/* FIXME: just queue a save, to make things a bit easier on
+	 * the resources */
+	panel_applet_save_position (info, info->gconf_key);
 }
 
 static void
@@ -779,7 +790,8 @@ panel_popup_menu (GtkWidget *widget, gpointer data)
 	return panel_do_popup_menu (panel, basep, widget, 3, GDK_CURRENT_TIME);
 }
 
-static gboolean pointer_in_widget (GtkWidget *widget, GdkEventButton *event)
+static gboolean
+pointer_in_widget (GtkWidget *widget, GdkEventButton *event)
 {
 	int x, y;
 	int wx, wy;
@@ -797,6 +809,47 @@ static gboolean pointer_in_widget (GtkWidget *widget, GdkEventButton *event)
 		return TRUE;
 }
 
+static void
+queue_resize_button_widgets (GtkWidget *w, gpointer data)
+{
+	if (BUTTON_IS_WIDGET (w)) {
+		gtk_widget_queue_resize (w);
+	}
+}
+
+static gboolean
+panel_end_move (GtkWidget *widget, GdkEventButton *bevent)
+{
+	if (panel_dragged &&
+	    BASEP_IS_WIDGET (widget)) {
+		BasePWidget *basep = BASEP_WIDGET (widget);
+		basep_widget_set_pos (basep,
+				      (gint16)bevent->x_root, 
+				      (gint16)bevent->y_root);
+		basep->autohide_inhibit = FALSE;
+		basep_widget_queue_autohide (basep);
+
+		gtk_grab_remove (widget);
+		gdk_pointer_ungrab (bevent->time);
+		panel_dragged = FALSE;
+		if (panel_dragged_timeout != 0)
+			g_source_remove (panel_dragged_timeout);
+		panel_dragged_timeout = 0;
+		panel_been_moved = FALSE;
+		if (pointer_in_widget (basep->panel, bevent) &&
+		    ! gtk_widget_is_focus (basep->panel))
+			panel_widget_focus (PANEL_WIDGET (basep->panel));
+
+		/* FIXME: why is this neccessary!!!!???? */
+		gtk_container_foreach (GTK_CONTAINER (basep->panel),
+				       queue_resize_button_widgets,
+				       NULL);
+
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static gboolean
 panel_event(GtkWidget *widget, GdkEvent *event)
 {
@@ -816,7 +869,10 @@ panel_event(GtkWidget *widget, GdkEvent *event)
 	switch (event->type) {
 	case GDK_BUTTON_PRESS:
 		bevent = (GdkEventButton *) event;
-		switch(bevent->button) {
+		if (panel_dragged) {
+			return panel_end_move (widget, bevent);
+		}
+		switch (bevent->button) {
 		case 3:
 			/* Store the point where the popup menu was started to
 			 * insert applets at that point */
@@ -841,34 +897,19 @@ panel_event(GtkWidget *widget, GdkEvent *event)
 
 	case GDK_BUTTON_RELEASE:
 		bevent = (GdkEventButton *) event;
-		if(panel_dragged) {
-			if (basep) {
-				basep_widget_set_pos(basep,
-						     (gint16)bevent->x_root, 
-						     (gint16)bevent->y_root);
-				basep->autohide_inhibit = FALSE;
-				basep_widget_queue_autohide(BASEP_WIDGET(widget));
-
-				gdk_pointer_ungrab(bevent->time);
-				gtk_grab_remove(widget);
-				panel_dragged = FALSE;
-				panel_dragged_timeout = -1;
-				panel_been_moved = FALSE;
-			}
-			if (pointer_in_widget (basep->panel, bevent) &&
-			    !gtk_widget_is_focus (basep->panel))
-				panel_widget_focus (panel);
-			return TRUE;
+		if (panel_dragged) {
+			return panel_end_move (widget, bevent);
 		}
 		break;
 	case GDK_MOTION_NOTIFY:
 		if (panel_dragged) {
-			if(panel_dragged_timeout==-1) {
+			if (panel_dragged_timeout == 0) {
 				panel_been_moved = FALSE;
-				move_panel_to_cursor(widget);
-				panel_dragged_timeout = gtk_timeout_add (30,panel_move_timeout,widget);
-			} else
+				move_panel_to_cursor (widget);
+				panel_dragged_timeout = g_timeout_add (30, panel_move_timeout, widget);
+			} else {
 				panel_been_moved = TRUE;
+			}
 		}
 		break;
 
@@ -882,12 +923,20 @@ panel_event(GtkWidget *widget, GdkEvent *event)
 static gboolean
 panel_widget_event (GtkWidget *widget, GdkEvent *event, GtkWidget *panelw)
 {
+	if (commie_mode)
+		return FALSE;
+
 	if (event->type == GDK_BUTTON_PRESS) {
 		GdkEventButton *bevent = (GdkEventButton *) event;
 
 		if (bevent->button == 1 ||
-		    bevent->button == 2)
-			return panel_initiate_move (panelw, bevent->time);
+		    bevent->button == 2) {
+			if (panel_dragged) {
+				return panel_end_move (widget, bevent);
+			} else {
+				return panel_initiate_move (panelw, bevent->time);
+			}
+		}
 	}
 
 	return FALSE;
@@ -1756,8 +1805,9 @@ panel_setup(GtkWidget *panelw)
 			  G_CALLBACK (panel_event), NULL);
 	g_signal_connect (G_OBJECT (panel), "popup_menu",
                           G_CALLBACK (panel_popup_menu), panelw);
-	g_signal_connect (G_OBJECT (panel), "event",
-			  G_CALLBACK (panel_widget_event), panelw);
+	if ( ! FOOBAR_IS_WIDGET(panelw))
+		g_signal_connect (G_OBJECT (panel), "event",
+				  G_CALLBACK (panel_widget_event), panelw);
 	
 	gtk_widget_set_events(panelw,
 			      gtk_widget_get_events(panelw) |
@@ -2436,6 +2486,8 @@ panel_save_to_gconf (PanelData *pd)
 	const gchar *profile;
 	char        *key;
 	char	    *color;
+
+	g_return_if_fail (pd != NULL);
 	
 	if (BASEP_IS_WIDGET (pd->panel)) {
 		basep = BASEP_WIDGET (pd->panel);
@@ -2564,7 +2616,7 @@ panel_save_to_gconf (PanelData *pd)
 		break;
 	case FOOBAR_PANEL:
 		panel_set_string (profile, panel->unique_id,
-				  "clock-format",FOOBAR_WIDGET (pd->panel)->clock_format);
+				  "clock-format", FOOBAR_WIDGET (pd->panel)->clock_format);
 
 		panel_set_int (profile, panel->unique_id, 
 			       "screen_id", FOOBAR_WIDGET (pd->panel)->screen);
@@ -2595,10 +2647,11 @@ panel_remove_from_gconf (PanelWidget *panel)
 					       PANEL_WIDGET (panel)->unique_id);
 
                         panel_gconf_clean_dir (panel_gconf_get_client (), dir);
-
-                        g_free (key);
-		} else
+			g_free (dir);
+			g_free (l->data);
+		} else {
 			new_panels = g_slist_prepend (new_panels, l->data);
+		}
         }
 
 	g_slist_free (panels);
